==> haskell-tasty-kat-0.0.3-169-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-5jqfKqfALBCJMZwo8JdvUC
key:                  tasty-kat-0.0.3-5jqfKqfALBCJMZwo8JdvUC
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  3141416f1d295b04971a447bcb6a42a1
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-5jqfKqfALBCJMZwo8JdvUC
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    tasty-1.4.3-45V6IUrFvI6FX8Qf0XPHba

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-kat-0.0.3-171-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-C82wQxSO4nqEshZZHpafYV
key:                  tasty-kat-0.0.3-C82wQxSO4nqEshZZHpafYV
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  9adfafbf41d15a4bef4e776d411c03ab
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-C82wQxSO4nqEshZZHpafYV
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
